package de.hhu.ba.yoshikoWrapper.swing.components;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.IOException;
import java.net.URI;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JOptionPane;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;
import de.hhu.ba.yoshikoWrapper.help.HelpLinks;
import de.hhu.ba.yoshikoWrapper.swing.GraphicsLoader;

@SuppressWarnings("serial")
public class HelpButton extends JButton{

	/**
	 * The final size (width and height) of the help button in pixel, declared here for better code maintainability
	 */
	private static final int SIZE = 16;

	/**
	 * The default icon for the help button that should be shown if the button is not highlighted
	 */
	private static final ImageIcon defaultIcon = GraphicsLoader.getInfoIcon(SIZE);
	/**
	 * The icon tor the help button that should be shown if the button is highlighted
	 */
	private static final ImageIcon hlIcon = GraphicsLoader.getInfoIconHL(SIZE);

	public HelpButton() {
		super(defaultIcon);
		setToolTipText(LocalizationManager.get("tooltip_helpButton"));
		setBorder(BorderFactory.createEmptyBorder());
		addActionListener(
			new ActionListener() {
				@Override
				public void actionPerformed(ActionEvent e) {
					URI uri = HelpLinks.getHelpLink(getParent().getClass());
					if (uri != null) {
						try {
							java.awt.Desktop.getDesktop().browse(uri);
						} catch (IOException ex) {
							JOptionPane.showMessageDialog(null, "DEBUG: Thesis is currently not online! Works only on my pc!");
							ex.printStackTrace();
						}
					}
				}
			}
		);
		//Add mouse listener (cosmetic only)
		addMouseListener(new MouseListener() {
			@Override
			public void mouseClicked(MouseEvent e) {}
			@Override
			public void mousePressed(MouseEvent e) {}
			@Override
			public void mouseReleased(MouseEvent e) {}
			@Override
			public void mouseEntered(MouseEvent e) {
				setIcon(hlIcon);
			}
			@Override
			public void mouseExited(MouseEvent e) {
				setIcon(defaultIcon);
			}
		});
	}
}
