/*******************************************************************************
 * Copyright (C) 2017 Philipp Spohr
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package de.hhu.ba.yoshikoWrapper.swing.components;

import java.awt.Color;

import javax.swing.JLabel;
import javax.swing.JPanel;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;
import de.hhu.ba.yoshikoWrapper.core.YoshikoLoader;
import de.hhu.ba.yoshikoWrapper.swig.LibraryInterface;
import de.hhu.ba.yoshikoWrapper.swing.GraphicsLoader;
/**
 * Simple JPanel visually representing whether or not the Yoshiko Lib is loaded and showing some basic info
 *
 */
@SuppressWarnings("serial")
public class LibStatusPanel extends JPanel {

	final JLabel yoshikoVersionLabel;

	public LibStatusPanel() {
		yoshikoVersionLabel = new JLabel();
		this.add(yoshikoVersionLabel);
	}

	/**
	 * Adjusts the style accordingly by changing its color and updating its text
	 */
	public void setStyle(boolean libraryLoaded) {
		if(libraryLoaded) {
			yoshikoVersionLabel.setText(LocalizationManager.get("yoshVersion")+" "+YoshikoLoader.REQUIRED_VERSION+"("+LibraryInterface.getVersionString()+")");
			yoshikoVersionLabel.setForeground(GraphicsLoader.yoshikoGreen);
		}
		else {
			yoshikoVersionLabel.setText(LocalizationManager.get("noLibTitle"));
			yoshikoVersionLabel.setForeground(Color.RED);
		}
	}

}
